<?php
namespace Teknisa\MYO\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DB\StoredProcedure\Param; 
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

class RequisicaoPedidosReport extends \Zeedhi\Framework\Controller\Report {

    protected $newCode;
    protected $birtStrategy;
    protected $environment;
    protected $crudService;
    protected $dataSourceManager;
    protected $dataSourceName;
    protected $nrlista;

    public function __construct(ReportService $reportService, $newCode, $birtStrategy, $environment, $crudService, $dataSourceManager) {
        $this->reportService = $reportService;
        $this->newCode       = $newCode;
        $this->birtStrategy = $birtStrategy;
        $this->environment   = $environment;
        $this->crudService   = $crudService;
        $this->dataSourceManager = $dataSourceManager;
    }

    protected $reportMapping = array (
        'MYO00300' =>
        array (
            'strategy' => 'BIRT', 
            'parameterMapping' =>
            array (
                'CDFILIAL'    => 'CDFILIAL',
                'DTINICIAL'   => 'DTINICIAL',
                'DTFINAL'     => 'DTFINAL',
                'NRORG'       => 'NRORG',
                'SERVICOS'    => 'SERVICOS',
                'PEDIDOS'     => 'PEDIDOS',
                'CDPICTPROD'  => 'CDPICTPROD'
            )
            ),
        'MYO00301' =>
        array (
            'strategy' => 'BIRT', 
            'parameterMapping' =>
            array (
                'CDFILIAL'    => 'CDFILIAL',
                'DTINICIAL'   => 'DTINICIAL',
                'DTFINAL'     => 'DTFINAL',
                'NRORG'       => 'NRORG',
                'SERVICOS'    => 'SERVICOS',
                'PEDIDOS'     => 'PEDIDOS',
                'CDPICTPROD'  => 'CDPICTPROD'
            )
        )
    );

    /**
     * prepareParameters
     * Verifica e realiza se necessário fazer o implode do parametro
     * caso não, retorna 'T' 
     *
     * @param Row $row
     * @param string $name
     *
     * @return string
     */
    private function prepareParameters($row, $name){
        if(isset($row[$name])) {
            if (!empty($row[$name])) {
                return '_'.implode('_', $row[$name]).'_';
            }
        }
        return 'T';
    }

    /**
     * getValueByField
     *
     * @param Row $row
     * @param string $checkField
     * @param string $field
     *
     * @return string
     */
    private function getValueByField($row, $checkField, $field){
        if(isset($row[$checkField])) {
            return 'T';
        }else {
            return $row[$field];
        }
    }

    /**
     * beforeProcessReport
     * Chamado pelo Report::createRemoteReport, adiciona os
     * campos na $row conforme especificado pelo relatório.
     *
     * @param Row $request
     * @param Response $response
     * 
     * @return void
     */
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();

        $row["NRORG"]    = $this->environment->getNrOrg();
        $row["SERVICOS"] = $this->prepareParameters($row, "NMSERVICO");
        $row["PEDIDOS"]  = $this->prepareParameters($row, "NRPEDIDOSERV");

        $this->birtStrategy->setReportFormat(strtolower($row['QR2TYPE']));
        //var_dump($row);
    }

}